History
=======

0.1.1 - 2015-12-16
------------------

- Fix broken packaging.

0.1.0 - 2015-12-16
------------------

This initial version is completely identical to what has been in Kotti core
before Kotti 1.3.0-dev.  **Don't even try to install with those versions!**

- Move all image related code from Kotti core into this package.
- Create package with ``pcreate -s kotti kotti_image``.
